nopreceiver

package module
v0.152.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 19, 2026 License: Apache-2.0 Imports: 7 Imported by: 5

README

No-op Receiver

Status
Stability alpha: profiles
beta: traces, metrics, logs
Distributions core, contrib
Issues Open issues Closed issues
Code Owners @evan-bradley

Serves as a placeholder receiver in a pipeline. This can be useful if you want to e.g. start a Collector with only extensions enabled.

Getting Started

All that is required to enable the No-op receiver is to include it in the receiver definitions. It takes no configuration.

receivers:
  nop:

Documentation

Overview

Package nopreceiver serves as a placeholder receiver.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewFactory

func NewFactory() xreceiver.Factory

NewFactory returns a receiver.Factory that constructs nop receivers.

Types

This section is empty.

Directories

Path Synopsis
internal
metadata
Package metadata contains the autogenerated telemetry and build information for the receiver/nop component.
Package metadata contains the autogenerated telemetry and build information for the receiver/nop component.

Jump to